@@ -1,3 +1,3 @@
 #! /bin/sh
 $EXTRACTRC `find . -name "*.ui" -o -name "*.rc" -o -name "*.kcfg" ` >> rc.cpp
-$XGETTEXT `find . -name "*.cpp" -o -name "*.h"` -o $podir/gwenview.pot
+$XGETTEXT `find . -name "*.cpp" -o -name "*.h" | grep -v '/tests/'` -o $podir/gwenview.pot
