@@ -31,6 +31,7 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 // KF
 #include <KAboutData>
 #include <KActionCollection>
+#include <KCrash>
 #include <KIO/CopyJob>
 #include <KLocalizedString>
 
@@ -186,6 +187,8 @@ int main(int argc, char *argv[])
     KAboutData::setApplicationData(*aboutData);
     QApplication::setWindowIcon(QIcon::fromTheme(QStringLiteral("gwenview"), app.windowIcon()));
 
+    KCrash::initialize();
+
     QCommandLineParser parser;
     aboutData.data()->setupCommandLine(&parser);
     parser.addOption(QCommandLineOption(QStringList() << QStringLiteral("f") << QStringLiteral("fullscreen"), i18n("Start in fullscreen mode")));
